local PipelineLinting = {
  kind: 'pipeline',
  name: 'linting',
  platform: {
    os: 'linux',
    arch: 'amd64',
  },
  steps: [
    {
      name: 'ansible-later',
      image: 'thegeeklab/ansible-later',
      commands: [
        'ansible-later',
      ],
    },
  ],
  trigger: {
    ref: ['refs/heads/master', 'refs/tags/**', 'refs/pull/**'],
  },
};

local PipelineDocumentation = {
  kind: 'pipeline',
  name: 'documentation',
  platform: {
    os: 'linux',
    arch: 'amd64',
  },
  steps: [
    {
      name: 'generate',
      image: 'thegeeklab/ansible-doctor',
      environment: {
        ANSIBLE_DOCTOR_LOG_LEVEL: 'INFO',
        ANSIBLE_DOCTOR_FORCE_OVERWRITE: true,
        ANSIBLE_DOCTOR_EXCLUDE_FILES: 'molecule/',
        ANSIBLE_DOCTOR_TEMPLATE: 'hugo-book',
        ANSIBLE_DOCTOR_ROLE_NAME: '${DRONE_REPO_NAME#*.}',
        ANSIBLE_DOCTOR_OUTPUT_DIR: '_docs/',
      },
    },
    {
      name: 'publish',
      image: 'plugins/gh-pages',
      settings: {
        remote_url: 'https://gitea.rknet.org/ansible/${DRONE_REPO_NAME}',
        netrc_machine: 'gitea.rknet.org',
        username: { from_secret: 'gitea_username' },
        password: { from_secret: 'gitea_token' },
        pages_directory: '_docs/',
        target_branch: 'docs',
      },
      when: {
        ref: ['refs/heads/master'],
      },
    },
  ],
  trigger: {
    ref: ['refs/heads/master', 'refs/tags/**', 'refs/pull/**'],
  },
  depends_on: [
    'linting',
  ],
};

local PipelineNotification = {
  kind: 'pipeline',
  name: 'notification',
  platform: {
    os: 'linux',
    arch: 'amd64',
  },
  clone: {
    disable: true,
  },
  steps: [
    {
      name: 'matrix',
      image: 'plugins/matrix',
      settings: {
        homeserver: { from_secret: 'matrix_homeserver' },
        roomid: { from_secret: 'matrix_roomid' },
        template: 'Status: **{{ build.status }}**<br/> Build: [{{ repo.Owner }}/{{ repo.Name }}]({{ build.link }}) ({{ build.branch }}) by {{ build.author }}<br/> Message: {{ build.message }}',
        username: { from_secret: 'matrix_username' },
        password: { from_secret: 'matrix_password' },
      },
    },
  ],
  depends_on: [
    'documentation',
  ],
  trigger: {
    status: ['success', 'failure'],
    ref: ['refs/heads/master', 'refs/tags/**'],
  },
};

[
  PipelineLinting,
  PipelineDocumentation,
  PipelineNotification,
]
